import { EncryptionProvider } from "../encryption/encryption.provider";
import { User } from "./user";
import { IHttpClient } from "../http/i-http-client";
import { TeamMemberDto } from "../team/dto/team-member-dto";
import { LocalSecretDto } from "../encryptable-dto/local-secret-dto";
import { GetSecretUsersResponseDto } from "../vault/dto/get-secret-users-response-dto";
import { CreateTemporaryUserResponseDto } from "./dto/create-temporary-user-response-dto";
import { FavouriteAccessOption } from "./access-option";
export declare class UserProvider {
    private readonly apiEndpoint;
    private readonly httpClient;
    private readonly encryptionProvider;
    constructor(apiEndpoint: string, httpClient: IHttpClient, encryptionProvider: EncryptionProvider);
    signUp(firstName: string, lastName: string, teamName: string, email: string, password: string, invitationCode: string, integrationSecretId?: string): Promise<User>;
    register(firstName: string, lastName: string, teamName: string, email: string, password: string, accessOption?: FavouriteAccessOption): Promise<User>;
    signIn(email: string, password: string, isWebApp?: boolean): Promise<User>;
    createTemporaryUser(email: string, firstName: string, lastName: string): Promise<CreateTemporaryUserResponseDto>;
    deleteUser(userIdToDelete: string, teamMembers: TeamMemberDto[], secrets: LocalSecretDto[], secretsUsers: GetSecretUsersResponseDto[]): Promise<void>;
    updateCustomParameters(userId: string, customParameters: string): Promise<void>;
    getCustomParameters(): Promise<string>;
    isEmailUnique(email: string): Promise<boolean>;
    private getLoggedUser;
}
